==> kubernetes-model-4.7.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/discovery/EndpointSliceFluent.java <==
package io.fabric8.kubernetes.api.model.discovery;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface EndpointSliceFluent<A extends EndpointSliceFluent<A>> extends Fluent<A>{


    public String getAddressType();
    public A withAddressType(String addressType);
    public Boolean hasAddressType();
    public A withNewAddressType(String arg1);
    public A withNewAddressType(StringBuilder arg1);
    public A withNewAddressType(StringBuffer arg1);
    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToEndpoints(int index,Endpoint item);
    public A setToEndpoints(int index,Endpoint item);
    public A addToEndpoints(Endpoint... items);
    public A addAllToEndpoints(Collection<Endpoint> items);
    public A removeFromEndpoints(Endpoint... items);
    public A removeAllFromEndpoints(Collection<Endpoint> items);
    public A removeMatchingFromEndpoints(io.fabric8.kubernetes.api.builder.Predicate<EndpointBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildEndpoints instead.
 * @return The buildable object.
 */
@Deprecated public List<Endpoint> getEndpoints();
    public List<Endpoint> buildEndpoints();
    public Endpoint buildEndpoint(int index);
    public Endpoint buildFirstEndpoint();
    public Endpoint buildLastEndpoint();
    public Endpoint buildMatchingEndpoint(io.fabric8.kubernetes.api.builder.Predicate<EndpointBuilder> predicate);
    public Boolean hasMatchingEndpoint(io.fabric8.kubernetes.api.builder.Predicate<EndpointBuilder> predicate);
    public A withEndpoints(List<Endpoint> endpoints);
    public A withEndpoints(Endpoint... endpoints);
    public Boolean hasEndpoints();
    public EndpointSliceFluent.EndpointsNested<A> addNewEndpoint();
    public EndpointSliceFluent.EndpointsNested<A> addNewEndpointLike(Endpoint item);
    public EndpointSliceFluent.EndpointsNested<A> setNewEndpointLike(int index,Endpoint item);
    public EndpointSliceFluent.EndpointsNested<A> editEndpoint(int index);
    public EndpointSliceFluent.EndpointsNested<A> editFirstEndpoint();
    public EndpointSliceFluent.EndpointsNested<A> editLastEndpoint();
    public EndpointSliceFluent.EndpointsNested<A> editMatchingEndpoint(io.fabric8.kubernetes.api.builder.Predicate<EndpointBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public EndpointSliceFluent.MetadataNested<A> withNewMetadata();
    public EndpointSliceFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public EndpointSliceFluent.MetadataNested<A> editMetadata();
    public EndpointSliceFluent.MetadataNested<A> editOrNewMetadata();
    public EndpointSliceFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    public A addToPorts(int index,io.fabric8.kubernetes.api.model.discovery.EndpointPort item);
    public A setToPorts(int index,io.fabric8.kubernetes.api.model.discovery.EndpointPort item);
    public A addToPorts(io.fabric8.kubernetes.api.model.discovery.EndpointPort... items);
    public A addAllToPorts(Collection<io.fabric8.kubernetes.api.model.discovery.EndpointPort> items);
    public A removeFromPorts(io.fabric8.kubernetes.api.model.discovery.EndpointPort... items);
    public A removeAllFromPorts(Collection<io.fabric8.kubernetes.api.model.discovery.EndpointPort> items);
    public A removeMatchingFromPorts(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.discovery.EndpointPortBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildPorts instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.kubernetes.api.model.discovery.EndpointPort> getPorts();
    public List<io.fabric8.kubernetes.api.model.discovery.EndpointPort> buildPorts();
    public io.fabric8.kubernetes.api.model.discovery.EndpointPort buildPort(int index);
    public io.fabric8.kubernetes.api.model.discovery.EndpointPort buildFirstPort();
    public io.fabric8.kubernetes.api.model.discovery.EndpointPort buildLastPort();
    public io.fabric8.kubernetes.api.model.discovery.EndpointPort buildMatchingPort(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.discovery.EndpointPortBuilder> predicate);
    public Boolean hasMatchingPort(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.discovery.EndpointPortBuilder> predicate);
    public A withPorts(List<io.fabric8.kubernetes.api.model.discovery.EndpointPort> ports);
    public A withPorts(io.fabric8.kubernetes.api.model.discovery.EndpointPort... ports);
    public Boolean hasPorts();
    public A addNewPort(String name,Integer port,String protocol);
    public EndpointSliceFluent.PortsNested<A> addNewPort();
    public EndpointSliceFluent.PortsNested<A> addNewPortLike(io.fabric8.kubernetes.api.model.discovery.EndpointPort item);
    public EndpointSliceFluent.PortsNested<A> setNewPortLike(int index,io.fabric8.kubernetes.api.model.discovery.EndpointPort item);
    public EndpointSliceFluent.PortsNested<A> editPort(int index);
    public EndpointSliceFluent.PortsNested<A> editFirstPort();
    public EndpointSliceFluent.PortsNested<A> editLastPort();
    public EndpointSliceFluent.PortsNested<A> editMatchingPort(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.discovery.EndpointPortBuilder> predicate);

    public interface EndpointsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EndpointFluent<EndpointSliceFluent.EndpointsNested<N>>{

        
    public N and();    public N endEndpoint();
}
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<EndpointSliceFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface PortsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.discovery.EndpointPortFluent<EndpointSliceFluent.PortsNested<N>>{

        
    public N and();    public N endPort();
}


}

==> kubernetes-model-4.9.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/discovery/EndpointSliceFluent.java <==
package io.fabric8.kubernetes.api.model.discovery;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface EndpointSliceFluent<A extends EndpointSliceFluent<A>> extends Fluent<A>{


    public String getAddressType();
    public A withAddressType(String addressType);
    public Boolean hasAddressType();
    public A withNewAddressType(String arg1);
    public A withNewAddressType(StringBuilder arg1);
    public A withNewAddressType(StringBuffer arg1);
    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToEndpoints(int index,Endpoint item);
    public A setToEndpoints(int index,Endpoint item);
    public A addToEndpoints(Endpoint... items);
    public A addAllToEndpoints(Collection<Endpoint> items);
    public A removeFromEndpoints(Endpoint... items);
    public A removeAllFromEndpoints(Collection<Endpoint> items);
    public A removeMatchingFromEndpoints(io.fabric8.kubernetes.api.builder.Predicate<EndpointBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildEndpoints instead.
 * @return The buildable object.
 */
@Deprecated public List<Endpoint> getEndpoints();
    public List<Endpoint> buildEndpoints();
    public Endpoint buildEndpoint(int index);
    public Endpoint buildFirstEndpoint();
    public Endpoint buildLastEndpoint();
    public Endpoint buildMatchingEndpoint(io.fabric8.kubernetes.api.builder.Predicate<EndpointBuilder> predicate);
    public Boolean hasMatchingEndpoint(io.fabric8.kubernetes.api.builder.Predicate<EndpointBuilder> predicate);
    public A withEndpoints(List<Endpoint> endpoints);
    public A withEndpoints(Endpoint... endpoints);
    public Boolean hasEndpoints();
    public EndpointSliceFluent.EndpointsNested<A> addNewEndpoint();
    public EndpointSliceFluent.EndpointsNested<A> addNewEndpointLike(Endpoint item);
    public EndpointSliceFluent.EndpointsNested<A> setNewEndpointLike(int index,Endpoint item);
    public EndpointSliceFluent.EndpointsNested<A> editEndpoint(int index);
    public EndpointSliceFluent.EndpointsNested<A> editFirstEndpoint();
    public EndpointSliceFluent.EndpointsNested<A> editLastEndpoint();
    public EndpointSliceFluent.EndpointsNested<A> editMatchingEndpoint(io.fabric8.kubernetes.api.builder.Predicate<EndpointBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public EndpointSliceFluent.MetadataNested<A> withNewMetadata();
    public EndpointSliceFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public EndpointSliceFluent.MetadataNested<A> editMetadata();
    public EndpointSliceFluent.MetadataNested<A> editOrNewMetadata();
    public EndpointSliceFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    public A addToPorts(int index,DiscoveryEndpointPort item);
    public A setToPorts(int index,DiscoveryEndpointPort item);
    public A addToPorts(DiscoveryEndpointPort... items);
    public A addAllToPorts(Collection<DiscoveryEndpointPort> items);
    public A removeFromPorts(DiscoveryEndpointPort... items);
    public A removeAllFromPorts(Collection<DiscoveryEndpointPort> items);
    public A removeMatchingFromPorts(io.fabric8.kubernetes.api.builder.Predicate<DiscoveryEndpointPortBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildPorts instead.
 * @return The buildable object.
 */
@Deprecated public List<DiscoveryEndpointPort> getPorts();
    public List<DiscoveryEndpointPort> buildPorts();
    public DiscoveryEndpointPort buildPort(int index);
    public DiscoveryEndpointPort buildFirstPort();
    public DiscoveryEndpointPort buildLastPort();
    public DiscoveryEndpointPort buildMatchingPort(io.fabric8.kubernetes.api.builder.Predicate<DiscoveryEndpointPortBuilder> predicate);
    public Boolean hasMatchingPort(io.fabric8.kubernetes.api.builder.Predicate<DiscoveryEndpointPortBuilder> predicate);
    public A withPorts(List<DiscoveryEndpointPort> ports);
    public A withPorts(DiscoveryEndpointPort... ports);
    public Boolean hasPorts();
    public A addNewPort(String appProtocol,String name,Integer port,String protocol);
    public EndpointSliceFluent.PortsNested<A> addNewPort();
    public EndpointSliceFluent.PortsNested<A> addNewPortLike(DiscoveryEndpointPort item);
    public EndpointSliceFluent.PortsNested<A> setNewPortLike(int index,DiscoveryEndpointPort item);
    public EndpointSliceFluent.PortsNested<A> editPort(int index);
    public EndpointSliceFluent.PortsNested<A> editFirstPort();
    public EndpointSliceFluent.PortsNested<A> editLastPort();
    public EndpointSliceFluent.PortsNested<A> editMatchingPort(io.fabric8.kubernetes.api.builder.Predicate<DiscoveryEndpointPortBuilder> predicate);

    public interface EndpointsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EndpointFluent<EndpointSliceFluent.EndpointsNested<N>>{

        
    public N and();    public N endEndpoint();
}
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<EndpointSliceFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface PortsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DiscoveryEndpointPortFluent<EndpointSliceFluent.PortsNested<N>>{

        
    public N and();    public N endPort();
}


}
